Window

Struct Window 

pub struct Window {
    pub viewport: Viewport,
    /* private fields */
}
Terminal-based “window” that renders frames via SoftwareRenderer.

Renders a 3-D scene to an RGBA framebuffer then presents it either as coloured ANSI art in the terminal (present_terminal) or drives a full animation loop (run).

Fields

viewport: Viewport

Implementations

Source

impl Window

pub fn new(viewport: Viewport) -> Self

pub fn with_terminal_dimensions(self, cols: usize, rows: usize) -> Self

pub fn render_scene(&mut self, scene: &Scene, camera: &Camera3D) -> FrameBuffer

Render the scene into the internal framebuffer and return a clone.

pub fn present_terminal(&mut self)

Present the last rendered frame to the terminal as ANSI art.

pub fn run( &mut self, scene: Scene, camera: Camera3D, tick: impl FnMut(u64, &mut Scene, &mut Camera3D), max_frames: u64, )

Drive the render / tick / present loop for max_frames frames.